CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
35 lines
1.4 KiB
Plaintext
35 lines
1.4 KiB
Plaintext
// RUN: %run_test hipify "%s" "%t" %hipify_args %clang_args
|
|
// CHECK: #include <hip/hip_runtime.h>
|
|
#include <iostream>
|
|
#define THRUST_NS_QUALIFIER ::thrust
|
|
// CHECK: #include <hipcub/hipcub.hpp>
|
|
#include <cub/cub.cuh>
|
|
|
|
// using namespace hipcub;
|
|
using namespace cub;
|
|
|
|
// Simple CUDA kernel for computing tiled partial sums
|
|
template <int BLOCK_THREADS, int ITEMS_PER_THREAD,
|
|
// CHECK: hipcub::BlockLoadAlgorithm LOAD_ALGO,
|
|
cub::BlockLoadAlgorithm LOAD_ALGO,
|
|
// CHECK: hipcub::BlockScanAlgorithm SCAN_ALGO>
|
|
cub::BlockScanAlgorithm SCAN_ALGO>
|
|
__global__ void ScanTilesKernel(int *d_in, int *d_out) {
|
|
// Specialize collective types for problem context
|
|
// CHECK: typedef ::hipcub::BlockLoad<int*, BLOCK_THREADS, ITEMS_PER_THREAD, LOAD_ALGO> BlockLoadT;
|
|
typedef ::cub::BlockLoad<int*, BLOCK_THREADS, ITEMS_PER_THREAD, LOAD_ALGO> BlockLoadT;
|
|
typedef BlockScan<int, BLOCK_THREADS, SCAN_ALGO> BlockScanT;
|
|
// Allocate on-chip temporary storage
|
|
__shared__ union {
|
|
typename BlockLoadT::TempStorage load;
|
|
typename BlockScanT::TempStorage reduce;
|
|
} temp_storage;
|
|
// Load data per thread
|
|
int thread_data[ITEMS_PER_THREAD];
|
|
int offset = blockIdx.x * (BLOCK_THREADS * ITEMS_PER_THREAD);
|
|
BlockLoadT(temp_storage.load).Load(d_in + offset, offset);
|
|
__syncthreads();
|
|
// Compute the block-wide prefix sum
|
|
BlockScanT(temp_storage).Sum(thread_data);
|
|
}
|